
<!--
FrozenIsBool False
-->

#Debugger

##Doc
----


> 
> The Debugger from a DebuggerClass instance has a debug function
> that prints in the console a state (to be defined) 
> of the environnement. This print can be indented with 
> the number of function frames from  which the process
> has passed through, for a nicer visualisation of the 
> kind of hooked functions. More options in the display
> can be possible like the number of the line in the corresponding
> code or the pick of KeyStrs helping for precising the 
> debugging instance identity.
> 
> 

----

<small>
View the Debugger notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Debugger.ipynb)
</small>

